@@ -1,18 +1,16 @@
-##############################################################################
-#
-# Copyright (c) 2002 Ingeniweb SARL
-#
-# This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
-# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
-# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE
-#
-##############################################################################
+# Copyright (c) 2003-2006 Ingeniweb SAS
+
+# This software is subject to the provisions of the GNU General Public
+# License, Version 2.0 (GPL).  A copy of the GPL should accompany this
+# distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
+# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY,
+# AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE
+
+# More details in the ``LICENSE`` file included in this package.
 
 """Attachment mixin.
-$Id: AttachmentMixin.py,v 1.6 2005/09/28 14:35:41 clebeaupin Exp $
+$Id: AttachmentMixin.py,v 1.9 2006/07/20 10:01:37 glenfant Exp $
 """
 
 __author__ = ''
@@ -598,4 +596,4 @@ class AttachmentContents:
             from_method = gen_method[1]
             permission = gen_method[2]
             methodGenerator().make(self, klass, from_method, to_method, permission)
-        
\ No newline at end of file
+        
