@@ -1,5 +1,16 @@
+# Copyright (c) 2003-2006 Ingeniweb SAS
+
+# This software is subject to the provisions of the GNU General Public
+# License, Version 2.0 (GPL).  A copy of the GPL should accompany this
+# distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
+# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY,
+# AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE
+
+# More details in the ``LICENSE`` file included in this package.
+
 """
-$Id: toolbox.py,v 1.3 2005/09/28 14:35:41 clebeaupin Exp $
+$Id: toolbox.py,v 1.6 2006/07/20 10:01:38 glenfant Exp $
 """
 
 __author__  = ''
@@ -35,4 +46,4 @@ def unindex_plonearticle_contents(self, portal_types=None):
             cat_tool.unindexObject(obj)
         
     out.write('Catalog rebuilt.\n')
-    return out.getvalue()
\ No newline at end of file
+    return out.getvalue()
