@@ -1,10 +1,17 @@
-#################################################################################
-#                                                                               #
-#                       copyright (c) 2003 Ingeniweb SARL                       #
-#                                                                               #
-#################################################################################
+# Copyright (c) 2003-2006 Ingeniweb SAS
 
-"""PloneArticleTool main class"""
+# This software is subject to the provisions of the GNU General Public
+# License, Version 2.0 (GPL).  A copy of the GPL should accompany this
+# distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
+# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY,
+# AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE
+
+# More details in the ``LICENSE`` file included in this package.
+
+"""PloneArticleTool main class
+$Id: PloneArticleTool.py,v 1.24 2006/07/20 10:01:38 glenfant Exp $
+"""
 
 # Python imports
 import StringIO
@@ -150,7 +157,7 @@ class PloneArticleTool(PropertyManager, UniqueObject, SimpleItem, ActionProvider
         self.safeEditProperty(self, 'max_attachment_size', 0, data_type='int')
         self.safeEditProperty(self, 'max_image_size', 0, data_type='int')
         self.safeEditProperty(self, 'preview_activated', 1, data_type='boolean')
-        self.safeEditProperty(self, 'site_text_formats', 'getAvailableTextFormats', data_type='multiple selection', new_value=['text/html',])
+        ## self.safeEditProperty(self, 'site_text_formats', 'getAvailableTextFormats', data_type='multiple selection', new_value=['text/html',])
         self.safeEditProperty(self, 'site_models', 'getAvailableModels', data_type='multiple selection', new_value=self.getAvailableModels())
         self.safeEditProperty(self, 'allowed_image_type', 'getAvailableImageTypesWithUndefined', data_type='selection', new_value=default_image_type)
         self.safeEditProperty(self, 'allowed_image_types', 'getAvailableImageTypes', data_type='multiple selection', new_value=image_types)
@@ -226,24 +233,24 @@ class PloneArticleTool(PropertyManager, UniqueObject, SimpleItem, ActionProvider
 ##        """ Sets the preview """
 ##        self.preview_activated=0
 
-    security.declarePublic("getAvailableTextFormats")
-    def getAvailableTextFormats(self):
-        """ get the availeble text formats """
-        return ('text/structured',
-                'text/restructured',
-                'text/html',
-                'text/plain',
-                'text/plain-pre',
-                'text/python-source',)
+##    security.declarePublic("getAvailableTextFormats")
+##    def getAvailableTextFormats(self):
+##        """ get the availeble text formats """
+##        return ('text/structured',
+##                'text/restructured',
+##                'text/html',
+##                'text/plain',
+##                'text/plain-pre',
+##                'text/python-source',)
 
-    security.declarePublic("getSiteTextFormats")
-    def getSiteTextFormats(self):
-        """ return the text formats for this site """
-        try:
-            site_text_formats = self.site_text_formats
-        except:
-            site_text_formats = ['html',]
-        return site_text_formats
+##    security.declarePublic("getSiteTextFormats")
+##    def getSiteTextFormats(self):
+##        """ return the text formats for this site """
+##        try:
+##            site_text_formats = self.site_text_formats
+##        except:
+##            site_text_formats = ['html',]
+##        return site_text_formats
 
 ##    def setSiteTextFormats(self, site_text_formats):
 ##        """ set the site text formats"""
