@@ -1,5 +1,16 @@
+# Copyright (c) 2003-2006 Ingeniweb SAS
+
+# This software is subject to the provisions of the GNU General Public
+# License, Version 2.0 (GPL).  A copy of the GPL should accompany this
+# distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
+# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY,
+# AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE
+
+# More details in the ``LICENSE`` file included in this package.
+
 """
-$Id: __init__.py,v 1.7 2005/04/26 17:59:04 clebeaupin Exp $
+$Id: __init__.py,v 1.12 2006/07/21 13:24:46 glenfant Exp $
 """
 
 __author__  = ''
@@ -10,11 +21,18 @@ import sys
 from Globals import package_home
 from Products.CMFCore import utils
 from Products.CMFCore import CMFCorePermissions
-from Products.Archetypes.public import *
+# from Products.Archetypes.public import *
 from Products.CMFCore.DirectoryView import registerDirectory
 from Products.PloneArticle.config import *
 from Products.PloneArticle import Permissions
 
+if HAS_LINGUA_PLONE:
+    from Products.LinguaPlone.public import process_types
+    from Products.LinguaPlone.public import listTypes
+else:
+    from Products.Archetypes.public import process_types
+    from Products.Archetypes.public import listTypes
+
 registerDirectory(SKINS_DIR, GLOBALS)
 
 def initialize(context):
@@ -39,5 +57,4 @@ def initialize(context):
     utils.ToolInit(
         PROJECTNAME + ' Tool',
         tools=(PloneArticleTool,),
-        product_name=PROJECTNAME,
         icon='tool.gif').initialize(context)
