@@ -1,7 +1,18 @@
+# Copyright (c) 2003-2006 Ingeniweb SAS
+
+# This software is subject to the provisions of the GNU General Public
+# License, Version 2.0 (GPL).  A copy of the GPL should accompany this
+# distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
+# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY,
+# AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE
+
+# More details in the ``LICENSE`` file included in this package.
+
 """
 PloneArticle base test
 
-$Id: testPloneArticle.py,v 1.9 2005/05/12 12:48:19 clebeaupin Exp $
+$Id: testPloneArticle.py,v 1.13 2006/07/20 11:56:00 glenfant Exp $
 """
 
 from common import *
@@ -16,6 +27,7 @@ class TestFile:
     def read(*args): return 'file_contents'
 
 tests = []
+
 class TestPloneArticle(PloneArticleTestCase):
     
     def testCreateArticle(self, ):
@@ -60,7 +72,8 @@ class TestPloneArticle(PloneArticleTestCase):
         self.assertEqual(1, len(attachments))
         
         #the attachment added is an ATFile
-        self.assertEqual(self.portal.portal_types.getTypeInfo('ATFile'), attachments[0].getTypeInfo())
+        self.assertEqual(self.portal.portal_types.getTypeInfo(FILE_PORTAL_TYPE),
+                         attachments[0].getTypeInfo())
 
         """
         from Products.PloneArticle.ArticleCore import ArticleContents
@@ -89,7 +102,8 @@ class TestPloneArticle(PloneArticleTestCase):
         attachment = self.article.getAttachment(uid)
         self.assertEqual(self.article.getAttachment(uid), attachments[0])
         #the return attachment is an ATFile
-        self.assertEqual(self.portal.portal_types.getTypeInfo('ATFile'), attachment.getTypeInfo())
+        self.assertEqual(self.portal.portal_types.getTypeInfo(FILE_PORTAL_TYPE),
+                         attachment.getTypeInfo())
     
     def testGetAttachmentBrain(self, ):
         """
